@@ -88,12 +88,12 @@ print.summary.selection <- function(x,
       if(part == "full") {
          cat("Probit selection equation:\n")
          printCoefmat( x$estimate[ x$param$index$betaS,,drop=FALSE],
-            signif.legend = FALSE )
+            signif.legend = FALSE, digits = digits )
       }
       if( x$tobitType == 2 ) {
          cat("Outcome equation:\n")
          printCoefmat( x$estimate[ x$param$index$betaO,,drop=FALSE],
-            signif.legend = ( part != "full" ) )
+            signif.legend = ( part != "full" ), digits = digits )
          if( x$method == "2step" ) {
             cat("Multiple R-Squared:", round(x$rSquared$R2, digits),
                ",\tAdjusted R-Squared:", round(x$rSquared$R2adj, digits),
@@ -102,7 +102,7 @@ print.summary.selection <- function(x,
       } else if( x$tobitType == 5 ) {
          cat("Outcome equation 1:\n")
          printCoefmat( x$estimate[ x$param$index$betaO1,,drop=FALSE],
-            signif.legend = FALSE )
+            signif.legend = FALSE, digits = digits )
          if( x$method == "2step" ) {
             cat("Multiple R-Squared:", round(x$rSquared$R21, digits),
                ",\tAdjusted R-Squared:", round(x$rSquared$R2adj1, digits),
@@ -110,7 +110,7 @@ print.summary.selection <- function(x,
          }
          cat("Outcome equation 2:\n")
          printCoefmat( x$estimate[ x$param$index$betaO2,,drop=FALSE],
-            signif.legend = ( part != "full" ) )
+            signif.legend = ( part != "full" ), digits = digits )
          if( x$method == "2step" ) {
             cat("Multiple R-Squared:", round(x$rSquared$R22, digits),
                ",\tAdjusted R-Squared:", round(x$rSquared$R2adj2, digits),
@@ -119,7 +119,8 @@ print.summary.selection <- function(x,
       }
       if(part=="full") {
          cat("Error terms:\n")
-         printCoefmat( x$estimate[ x$param$index$errTerms,,drop=FALSE] )
+         printCoefmat( x$estimate[ x$param$index$errTerms,,drop=FALSE],
+            digits = digits )
       }
    }
    cat("--------------------------------------------\n")
